/* $Revision: 1.3 $ $Date: 2003/10/30 03:50:02 $
   File:
     nrv-hh.sl
   Title:
     Hodgkin-Huxley Model
   Author:
     Yoshimi Kamiyama (kamiyama@ist.aichi-pu.ac.jp)
   Reference Paper:
     Hodgkin, A. L. and Huxley, A. F. (1952),
     A quantitative description of membrane current and its
     application to conduction and excitation in nerve,
     Journal of Physiology, Vol.117, pp.500-544 
*/
nassign("nrv-hh");
npp();
nlink("-O2");

series m,h,n;
series gNa,gK,INa,IK,IL;
series V;

nout(V,"HH",0,1);
nout(gK,"HH",0,3,"gK"); 
nout(h,"HH",0,3,"h"); 
nout(m,"HH",0,3,"m"); 
nout(n,"HH",0,3,"n"); 
nout(gNa,"HH",0,3,"gNa"); 

nstim("HH",0,"P",0,0,0,0,999);
ntime(25.0,0.01,0.01,0.1);
ninteg("F");
ncal();

ginit();
wopen(1,"A4",0,1);
size(120,50);
origin(40,150);
xtime=(0~2500)*0.01;
scale("N","F","N","F",-1,26,-20,110);
graph(V,xtime,0,0,1,3.5);
title(1,"time[msec]","membrane potential[mV]");	
axis(1,1,"Y","Y",3.5,0,3,5,50,0);
draw("Y",0);

origin(40,90);
scale("N","F","N","F",-1,26,-0.9,16);
graph(gK,xtime,0,0,1,3.5);
title(1,"time[msec]","gK[m.mho]");	
axis(1,1,"Y","Y",3.5,0,3,5,5,0);
label("I",40,10,3,0,"gK",0);

scale("N","F","N","F",-1,26,0,0.61);
graph(h,xtime,0,0,1,3.5);
title(1,"time[msec]","h");	
axis(1,3,"XY","XY",3.5,0,1,5,0.2,0);
label("I",40,40,3,0,"h",0);

